/*
 *   Copyright 2005 The Apache Software Foundation
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package org.apache.felix.moduleloader.search;

import java.util.EventListener;

import org.apache.felix.moduleloader.ModuleEvent;

/**
 * <p>
 * This is an event listener interface for listening to validation
 * events that are generated by the <tt>ImportSearchPolicy</tt>. Events
 * are fired when a module is validated and when it is invalidated.
 * </p>
 * @see org.apache.felix.moduleloader.search.ImportSearchPolicy
**/
public interface ValidationListener extends EventListener
{
    /**
     * This is an event callback method that indicates that
     * a module was validated.
     * @param event the module event containing the event data.
    **/
    public void moduleValidated(ModuleEvent event);

    /**
     * This is an event callback method that indicates that
     * a module was invalidated.
     * @param event the module event containing the event data.
    **/
    public void moduleInvalidated(ModuleEvent event);
}